match_better library
Better test assertions for Dart
Properties
Functions
-
containsAnyOf<
T> (Iterable< T> items) → Matcher -
A matcher that checks if an iterable contains any of the given
items. -
equalsButNotSameAs(
Object? other) → Matcher - A matcher that checks if two objects are equal but not the same instance.
-
returnsA<
T> () → Matcher -
A matcher that checks if a function returns a value of type
T.