containsAnyOf<T> function
A matcher that checks if an iterable contains any of the given items.
Implementation
Matcher containsAnyOf<T>(Iterable<T> items) => _ContainsAnyOf<T>(items.toSet());
A matcher that checks if an iterable contains any of the given items.
Matcher containsAnyOf<T>(Iterable<T> items) => _ContainsAnyOf<T>(items.toSet());