returnsA<T> function
Matcher
returnsA<T>()
A matcher that checks if a function returns a value of type T.
Implementation
Matcher returnsA<T>() => ReturnsA<T>();
A matcher that checks if a function returns a value of type T.
Matcher returnsA<T>() => ReturnsA<T>();