menu
expect_better package
documentation
match_better.dart
match_better.dart
dark_mode
light_mode
match_better
library
Better test assertions for Dart
Properties
isFalsy
→ Matcher
A matcher that checks if a value is "falsy".
no setter
isTruthy
→ Matcher
A matcher that checks if a value is "truthy".
no setter
Functions
containsAnyOf
<
T
>
(
Iterable
<
T
>
items
)
→ Matcher
A matcher that checks if an iterable contains any of the given
items
.
expect_better package
documentation
match_better.dart
expect_better
package
Libraries
expect_better
match_better
match_better library