match_better library

Better test assertions for Dart

Properties

isFalsy → Matcher
A matcher that checks if a value is "falsy".
no setter
isTruthy → Matcher
A matcher that checks if a value is "truthy".
no setter

Functions

containsAnyOf<T>(Iterable<T> items) → Matcher
A matcher that checks if an iterable contains any of the given items.